.. _spider_profil.at:

profil.at
---------
Newest articles from `profil <https://www.profil.at>`_.

Configuration
~~~~~~~~~~~~~
Add ``profil.at`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     profil.at

